window.Gleam.initSearch([{"doc":"glubsub","title":"glubsub","content":"# glubsub\n\n[![Package Version](https://img.shields.io/hexpm/v/glubsub)](https://hex.pm/packages/glubsub)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glubsub/)\n\ntiny pubsub inspired abstraction.\n\n```sh\ngleam add glubsub\n```\n\n```gleam\nimport gleam/otp/actor\nimport gleam/io\nimport glubsub\n\ntype Message {\n  Broadcast(String)\n}\n\npub fn main() {\n  let assert Ok(topic) = glubsub.new_topic()\n\n  let assert Ok(actor) = actor.start(Nil, handle_message)\n\n  glubsub.subscribe(topic, actor)\n\n  glubsub.broadcast(topic, Broadcast(&quot;Hello Wobble!&quot;))\n}\n\nfn handle_message(message: Message, state) -&gt; actor.Next(a, Nil) {\n  case message {\n    Broadcast(msg) -&gt; {\n      io.println(msg)\n      actor.continue(state)\n    }\n  }\n}\n```\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glubsub","title":"GlubsubError","content":"pub opaque type GlubsubError\n\n\nSynonyms:\nglubsub.GlubsubError\nglubsub GlubsubError","url":"glubsub.html#GlubsubError"},{"doc":"glubsub","title":"Message","content":"pub opaque type Message(m)\n\n\nSynonyms:\nglubsub.Message\nglubsub Message","url":"glubsub.html#Message"},{"doc":"glubsub","title":"Subscriber","content":"pub type Subscriber(m) {\n  Subscriber(client: Subject(m), monitor: ProcessMonitor)\n}\n\nSubscriber(client: Subject(m), monitor: ProcessMonitor)\n\n\nSynonyms:\nglubsub.Subscriber\nglubsub Subscriber","url":"glubsub.html#Subscriber"},{"doc":"glubsub","title":"Topic","content":"pub type Topic(m) {\n  Topic(Subject(Message(m)))\n}\n\nTopic(Subject(Message(m)))\n\n\nSynonyms:\nglubsub.Topic\nglubsub Topic","url":"glubsub.html#Topic"},{"doc":"glubsub","title":"broadcast","content":"pub fn broadcast(topic: Topic(a), message: a) -&gt; Result(Nil, Nil)\n Broadcasts a message to all subscribers of the given topic.\nSynonyms:\nglubsub.broadcast\nglubsub broadcast","url":"glubsub.html#broadcast"},{"doc":"glubsub","title":"destroy_topic","content":"pub fn destroy_topic(topic: Topic(a)) -&gt; Nil\n Destroys the given topic, unsubscribing all clients.\nSynonyms:\nglubsub.destroy_topic\nglubsub destroy_topic","url":"glubsub.html#destroy_topic"},{"doc":"glubsub","title":"get_subscribers","content":"pub fn get_subscribers(topic: Topic(a)) -&gt; List(Subscriber(a))\n Returns a set of all subscribers to the given topic.\nSynonyms:\nglubsub.get_subscribers\nglubsub get_subscribers","url":"glubsub.html#get_subscribers"},{"doc":"glubsub","title":"new_topic","content":"pub fn new_topic() -&gt; Result(Topic(a), GlubsubError)\n Creates a new topic. Which is a pubsub channel that clients can subscribe to.\nSynonyms:\nglubsub.new_topic\nglubsub new_topic","url":"glubsub.html#new_topic"},{"doc":"glubsub","title":"subscribe","content":"pub fn subscribe(\n  topic: Topic(a),\n  client: Subject(a),\n) -&gt; Result(Nil, GlubsubError)\n Subscribes the given client to the given topic.\nSynonyms:\nglubsub.subscribe\nglubsub subscribe","url":"glubsub.html#subscribe"},{"doc":"glubsub","title":"unsubscribe","content":"pub fn unsubscribe(\n  topic: Topic(a),\n  client: Subject(a),\n) -&gt; Result(Nil, GlubsubError)\n Unsubscribes the given client from the given topic.\nSynonyms:\nglubsub.unsubscribe\nglubsub unsubscribe","url":"glubsub.html#unsubscribe"},{"doc":"glubsub","title":"glubsub","content":" This module implements a simple pubsub system using gleam actors.\n","url":"glubsub.html"}]);